%global packname  qtl

Name:             R-%{packname}
Version:          1.19.20
Release:          2%{?dist}
Source0:          http://www.rqtl.org/download/%{packname}_1.19-20.tar.gz
License:          GPLv3
URL:              http://www.rqtl.org/
Group:            Applications/Engineering
Summary:          Tools for analyzing QTL experiments
Requires:         R-core >= 2.10
BuildRequires:    R-devel >= 2.10
%if %{?fedora}%{!?fedora:0} >= 9 || %{?rhel}%{!?rhel:0} >= 6
BuildRequires:    tex(latex)
%else
BuildRequires:    tetex-latex
%endif
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%description
R-qtl is an extensible, interactive environment for mapping
quantitative trait loci (QTLs) in experimental crosses. Our goal is to
make complex QTL mapping methods widely accessible and allow users to
focus on modeling rather than computing.

A key component of computational methods for QTL mapping is the hidden
Markov model (HMM) technology for dealing with missing genotype
data. We have implemented the main HMM algorithms, with allowance for
the presence of genotyping errors, for backcrosses, intercrosses, and
phase-known four-way crosses.

The current version of R-qtl includes facilities for estimating
genetic maps, identifying genotyping errors, and performing single-QTL
genome scans and two-QTL, two-dimensional genome scans, by interval
mapping (with the EM algorithm), Haley-Knott regression, and multiple
imputation. All of this may be done in the presence of covariates
(such as sex, age or treatment). One may also fit higher-order QTL
models by multiple imputation and Haley-Knott regression.

%prep
%setup -q -c -n %{packname}

%build

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_libdir}/R/library
R CMD INSTALL %{packname} -l %{buildroot}%{_libdir}/R/library
test -d %{packname}/src && (cd %{packname}/src; rm -f *.o *.so)
rm -rf %{buildroot}%{_libdir}/R/library/R.css

%check
# The check is disabled because it treats the non-presence of the
# suggested R-snow package as an error - this is an optional dependency
# not (yet) available in Fedora. R-qtl works without it.

# R CMD check %{packname}

%clean
rm -rf %{buildroot}

%files
%defattr(-, root, root, -)
%dir %{_libdir}/R/library/%{packname}
%doc %{_libdir}/R/library/%{packname}/docs
%doc %{_libdir}/R/library/%{packname}/html
%doc %{_libdir}/R/library/%{packname}/BUGS.txt
%doc %{_libdir}/R/library/%{packname}/DESCRIPTION
%doc %{_libdir}/R/library/%{packname}/LICENSE.txt
%doc %{_libdir}/R/library/%{packname}/MQM-TODO.txt
%doc %{_libdir}/R/library/%{packname}/README.txt
%doc %{_libdir}/R/library/%{packname}/STATUS.txt
%doc %{_libdir}/R/library/%{packname}/TODO.txt
%{_libdir}/R/library/%{packname}/CITATION
%{_libdir}/R/library/%{packname}/INDEX
%{_libdir}/R/library/%{packname}/Meta
%{_libdir}/R/library/%{packname}/R
%{_libdir}/R/library/%{packname}/data
%{_libdir}/R/library/%{packname}/help
%{_libdir}/R/library/%{packname}/libs
%{_libdir}/R/library/%{packname}/sampledata

%changelog
* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.19.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 19 2011 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.19.20-1
- New upstream release

* Thu Sep 02 2010 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.18.7-1
- New upstream release

* Fri Jun 11 2010 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.16.6-1
- New upstream release

* Sun Nov 22 2009 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.14.2-2
- Modify build for R 2.10 and higher - remove scriptlets

* Wed Oct 07 2009 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.14.2-1
- New upstream release
- Disable the check since it trips on a missing suggested package
- Change license tag to GPLv3 to reflect an upstream license change

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat May 23 2009 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.11-1
- New upstream release

* Wed Mar 18 2009 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.10-2
- Update package summary and description
- Change defines to globals

* Sat Feb 28 2009 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.10-1
- Updated to new upstream version - contains consistent licensing information
- Reverted License tag from GPLv2 to GPLv2+ to reflect the new information

* Tue Dec 02 2008 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.09-2
- Corrected License tag from GPLv2+ to GPLv2

* Wed Nov 05 2008 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.09-1
- Initial package creation
